==> relations-0.0.5.tar.gz: lib/bloc/stage_bloc.dart <==
import 'dart:async';
import 'package:bloc/bloc.dart';
import '../models/stage_session_data.dart';
import '../models/stage_theme.dart';
import '../view/stage_items/edge.dart';
import '../view/stage_items/wrapper_box.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/rendering.dart';
import './bloc.dart';
import 'package:rxdart/rxdart.dart';

class StageBloc extends Bloc<StageEvent, StageSessionData> {
  /// it is neccessary to provide static access to the bounds
  static Rect stageBounds;
  final Size stageSize;

  final StageTheme theme;

  /// Receiving the whole transform matrix,
  /// but all we need is to raise notification when only the scaling changes.
  PublishSubject<Matrix4> $stageTransformState;
  Stream<Matrix4> get stageTransformNotifier => $stageTransformState.stream;

  void changeScale(Matrix4 matrix) => $stageTransformState.add(matrix);

  StageBloc({@required this.stageSize, @required this.theme}) : super() {
    stageBounds = this.state.bounds;

    $stageTransformState = PublishSubject<Matrix4>();

    /// save it, because we want to provide this value for rebuilt items (Edge, WrapperBox)
    $stageTransformState.listen((Matrix4 data) =>
        this.state.stageScale = data.getMaxScaleOnAxis());
  }

  Offset get stageCenter => stageBounds.center;

  @override
  StageSessionData get initialState => StageSessionData(
      bounds: Rect.fromLTWH(0, 0, this.stageSize.width, this.stageSize.height),
      connectionEnabled: false);

  @override
  Stream<StageSessionData> mapEventToState(
    StageEvent event,
  ) async* {
    if (event is StageUpdateEvent) {
      // newstate
      final allround = state.copy();
      yield allround;
    }
  }

  void _updateState() {
    this.add(StageUpdateEvent());
  }

  void setConnectionMode(bool value) {
    state.connectionEnabled = value;
    _updateState();
  }

  void toggleConnectionMode() {
    state.connectionEnabled = !state.connectionEnabled;
    _updateState();
  }

  void setSelectedBox(WrapperBoxState box) {
    state.selectedEntity?.unselect();
    state.selectedEntity = box;
    state.selectedBox = box;
    state.selectedEntity.select();
  }

  void setTappedPos(Offset pos) {
    state.tappedPos = pos;
  }

  void setSelectedEdge(EdgeState edge) {
    state.selectedEntity?.unselect();
    state.selectedEntity = edge;
    state.selectedEdge = edge;
    state.selectedEntity.select();
  }

  void unselect() {
    state.selectedEntity?.unselect();
    state.selectedBox = null;
    state.selectedEdge = null;
    state.selectedEntity = null;
  }

  @override
  Future<void> close() {
    super.close();
    $stageTransformState.close();
    return Future<void>.value();
  }
}

==> relations-1.0.0.tar.gz: lib/bloc/stage_bloc.dart <==
import 'dart:async';
import 'package:bloc/bloc.dart';
import '../models/stage_session_data.dart';
import '../models/stage_theme.dart';
import '../view/stage_items/edge.dart';
import '../view/stage_items/wrapper_box.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/rendering.dart';
import './bloc.dart';
import 'package:rxdart/rxdart.dart';

class StageBloc extends Bloc<StageEvent, StageSessionData> {
  /// it is neccessary to provide static access to the bounds
  static Rect stageBounds;
  final Size stageSize;

  final StageTheme theme;

  /// Receiving the whole transform matrix,
  /// but all we need is to raise notification when only the scaling changes.
  PublishSubject<Matrix4> $stageTransformState;
  Stream<Matrix4> get stageTransformNotifier => $stageTransformState.stream;

  void changeScale(Matrix4 matrix) => $stageTransformState.add(matrix);

  StageBloc({@required this.stageSize, @required this.theme}) : super() {
    stageBounds = this.state.bounds;

    $stageTransformState = PublishSubject<Matrix4>();

    /// save it, because we want to provide this value for rebuilt items (Edge, WrapperBox)
    $stageTransformState.listen(
        (Matrix4 data) => this.state.stageScale = data.getMaxScaleOnAxis());
  }

  Offset get stageCenter => stageBounds.center;

  @override
  StageSessionData get initialState => StageSessionData(
      bounds: Rect.fromLTWH(0, 0, this.stageSize.width, this.stageSize.height),
      connectionEnabled: false);

  @override
  Stream<StageSessionData> mapEventToState(
    StageEvent event,
  ) async* {
    if (event is StageUpdateEvent) {
      // newstate
      final allround = state.copy();
      yield allround;
    }
  }

  void _updateState() {
    this.add(StageUpdateEvent());
  }

  void setConnectionMode(bool value) {
    state.connectionEnabled = value;
    _updateState();
  }

  void toggleConnectionMode() {
    state.connectionEnabled = !state.connectionEnabled;
    _updateState();
  }

  void setSelectedBox(WrapperBoxState box) {
    state.selectedEntity?.unselect();
    state.selectedEntity = box;
    state.selectedBox = box;
    state.selectedEntity.select();
  }

  void setTappedPos(Offset pos) {
    state.tappedPos = pos;
  }

  void setSelectedEdge(EdgeState edge) {
    state.selectedEntity?.unselect();
    state.selectedEntity = edge;
    state.selectedEdge = edge;
    state.selectedEntity.select();
  }

  void unselect() {
    state.selectedEntity?.unselect();
    state.selectedBox = null;
    state.selectedEdge = null;
    state.selectedEntity = null;
  }

  @override
  Future<void> close() {
    super.close();
    $stageTransformState.close();
    return Future<void>.value();
  }
}
